import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker, message, Upload, Table, Pagination } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import moment from 'moment';
import router from 'umi/router';
import apis from '../../../../../services/apis';
import BuildSelect from '../../../../../components/SelectButton/BuildSelect';
import AuthButton from '@/components/AuthButton';
import styles from './style.less';
import request from '../../../../../utils/request';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
const { TextArea } = Input;

const header = (props) => {
  const [ data, setData ] = useState({})
  const [page, changePage] = useState({})
  const raiseId = props.raiseId.raiseId
  const type = props.type

  useEffect(() => {
    getList({ pageNum: 1, pageSize: 10, raiseId : raiseId, type:type});
  },[])

  // 查询列表
  const getList = (params) => {
    request({ ...apis.house.paidOrderList, params: { ...params, raiseId:raiseId, type:type },}).then((data) => {
        console.log(data)
        setData(data)
    })
  }
  
  const columns = [
    {
      title: '缴费单编号',
      dataIndex: 'orderId',
      key: 'orderId',
      align: 'center',
    },
    {
      title: '认筹单编号',
      dataIndex: 'raiseRecordId',
      key: 'raiseRecordId',
      align: 'center',
    },
    {
      title: '用户手机号',
      dataIndex: 'personTel',
      key: 'personTel',
      align: 'center',
    },
    {
      title: '微信订单号',
      dataIndex: 'tradeNo',
      key: 'tradeNo',
      align: 'center',
    },
    {
      title: '实付金额',
      dataIndex: 'totalFee',
      key: 'totalFee',
      align: 'center',
    },
    {
      title: '支付成功时间',
      dataIndex: 'payTime',
      key: 'payTime',
      align: 'center',
      render: (x, row) => <><span>{`${moment(row.payTime).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
    },
    {
      title: '退费状态',
      // dataIndex: 'payStatus1',
      // key: 'payStatus1',
      align: 'center',
      render: (text, record) => (<><span>{record.payStatus === 'refunded' ? '已退费':'未退费'}</span></>),
    },
    {
      title: '退费结果',
      // dataIndex: 'payStatus2',
      // key: 'payStatus2',
      align: 'center',
      render: (text, record) => (<><span>{record.payStatus === 'refunded' ? '已退费':'未退费'}</span></>),
    },
    {
      title: '退费单编号',
      dataIndex: 'refundNo',
      key: 'refundNo',
      align: 'center',
    },
  ];
  
  const changePageNum = (pageNumber) => {
      getList({ pageNum: pageNumber, pageSize: 10, raiseId : raiseId, type:type, ...props.form.getFieldsValue() })
  }

  // 提交事件
const handleSubmit = (e, props) => {
  console.log('submitValuesubmitValuesubmitValue', props)
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        let {liveTime, ...submitValue} = values
        if (submitValue.payStartTime != null){
          submitValue.payStartTime = moment(submitValue.payStartTime).format('YYYY-MM-DD HH:mm:ss')
        }
        if (submitValue.payEndTime != null){
          submitValue.payEndTime = moment(submitValue.payEndTime).format('YYYY-MM-DD HH:mm:ss')
        }
        getList({ pageNum: 1, pageSize: 10, raiseId : raiseId,  ...submitValue })
      }
    });
  }

   //重置搜索
   function handleReset() {
    props.form.resetFields();
  }

  const { getFieldDecorator } = props.form
  return (

    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('orderId')(
            <Input placeholder="缴费单编号"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('raiseId')(
            <Input placeholder="认筹单编号"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('tel')(
            <Input placeholder="用户手机号"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('transactionId')(
            <Input placeholder="微信订单号"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('refundNo')(
            <Input placeholder="退费单编号"/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('shareType')(
            <Select style={{ width: '180px' }} placeholder="退费状态">
              <Option value="housePost">不限</Option>
              <Option value="houseApp">已发起</Option>
              <Option value="houseApp">已退费</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('shareType')(
            <Select style={{ width: '180px' }} placeholder="退费结果">
               <Option value="housePost">不限</Option>
               <Option value="houseApp">成功</Option>
               <Option value="houseApp">失败</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('payStartTime')(
            <DatePicker placeholder="支付成功开始时间"/>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('payEndTime')(
            <DatePicker placeholder="支付成功结束时间"/>,
          )}
        </Form.Item>  
        <Form.Item>
        <AuthButton name="admin.extendContent.search" noRight={null}>
          <Button type="primary" htmlType="submit" className={styles.searchBtn}>
            搜索
          </Button>
          </AuthButton>
          <Button style={{ marginLeft: 8 }} onClick={handleReset}>
              重置
            </Button>
        </Form.Item>
      </Form>
      <br/>
      <span>共筛选出{data.total}条数据</span>     
      <Table dataSource={data.records} columns={columns} pagination={false} rowKey="carouseFigureList"/>
      <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
        <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current}/>
      </div>
    </>
  )
}
const PaymentChips = Form.create({ name: 'header' })(header);

export default PaymentChips
